# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-12-17 13:01
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0004_auto_20191211_1552'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customer',
            old_name='firstName',
            new_name='first_name',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='lastName',
            new_name='last_name',
        ),
    ]
