# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-06-01 15:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0010_auto_20200522_1516'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='member',
            name='name',
        ),
    ]
