# Generated by Django 2.2.16 on 2020-11-30 14:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0015_auto_20200926_0911'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='team',
        ),
    ]
